#!/usr/bin/env python
# -*- coding: utf-8 -*-

# file      : prefs.py
# project   : fricorder
# copyright : (C) 2013 by Claude Bulin
#
# This file is part of fricorder project
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; version 3.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA


import os
from fconfig import FConfig
import configparser
# init the foreign language
import Language_Init

class Preferences:

	def init(self):
		# Add language support
		_ = Language_Init.Translator(FConfig).lang.gettext
		self._ = _
		self.config = []

	def Preferences_create_file(self):
		print('Preferences_create_file')

		config = configparser.ConfigParser()

		# only for information in file
		config['PACKAGE'] = {
			'Name_Package': FConfig.__PACKAGE__,
			'Package_Version': FConfig.__VERSION__,
			'Package_Url': FConfig.__URL__
			}
		# etat fileds
		config['STATE'] = {
			'NumChannel': 1,
			'NumDate': 0,
			'SbTime': 5,
			'NumQuality': 0,
			'e_dest': os.getenv("HOME")
			}
		# pos windows main
		config['WIN_MAIN_POS'] = {
			'MAIN_WIN_POS_X' : 700,
			'MAIN_WIN_POS_Y': 200,
			'WIN_WIDTH': 700,
			'WIN_HEIGHT': 500
			}

		with open(os.path.join(FConfig.CONFIGFILE, "fricorder.config"), 'w') as configfile:
			config.write(configfile)

	def Preferences_read_file(self):
		path = os.path.join(FConfig.CONFIGFILE, "fricorder.config")
		if not os.path.isfile( path ):
			print('create [ ' + path + ' ]')
			self.Preferences_create_file()

		print('Preferences_read_file')

		self.config = configparser.ConfigParser()
		self.config.read(os.path.join(FConfig.CONFIGFILE, "fricorder.config"))

		for key in self.config:
			print(' '*4 + key)
			for k in self.config[ key ]:
				str_k = "        " + k
				while len(str_k) < 25:
					str_k = str_k + " "
				str_k = str_k + self.config[ key ][ k ]
				print( str_k )

	def Preferences_save_file(self):
		print('Preferences_save_file')
		with open(os.path.join(FConfig.CONFIGFILE, "fricorder.config"), 'w') as configfile:
			self.config.write(configfile)

	def Preferences_get_win_width(self):
		if 'WIN_MAIN_POS' in self.config and 'win_width' in self.config[ 'WIN_MAIN_POS' ]:
			return int(self.config[ 'WIN_MAIN_POS' ][ 'win_width' ] )
		else:
			return 700

	def Preferences_get_win_height(self):
		if 'WIN_MAIN_POS' in self.config and 'win_height' in self.config[ 'WIN_MAIN_POS' ]:
			return int(self.config[ 'WIN_MAIN_POS' ][ 'win_height' ] )
		else:
			return 500

	def Preferences_get_main_win_pos_x(self):
		if 'WIN_MAIN_POS' in self.config and 'main_win_pos_x' in self.config[ 'WIN_MAIN_POS' ]:
			return int(self.config[ 'WIN_MAIN_POS' ][ 'main_win_pos_x' ] )
		else:
			return 700

	def Preferences_get_main_win_pos_y(self):
		if 'WIN_MAIN_POS' in self.config and 'main_win_pos_y' in self.config[ 'WIN_MAIN_POS' ]:
			return int(self.config[ 'WIN_MAIN_POS' ][ 'main_win_pos_y' ] )
		else:
			return 200

	def Preferences_get_dest(self):
		Path = self.config[ 'STATE' ][ 'e_dest' ]
		if os.path.isdir( Path ) == True:
			return Path
		return os.getenv("HOME")

	def Preferences_get_chaine_active(self):
		return int(self.config[ 'STATE' ][ 'NumChannel' ])

	def Preferences_get_jour_actif(self):
		return int(self.config[ 'STATE' ][ 'NumDate' ])

	def Preferences_get_quality_actif(self):
		return int(self.config[ 'STATE' ][ 'NumQuality' ])

	def Preferences_get_sb_time(self):
		return float(self.config[ 'STATE' ][ 'SbTime' ])

	def Preferences_save_op(self, form_e_dest, form_chaine, form_jour, form_quality, form_sb_time,  x, y, w, h):
		print('Preferences_save_op')

		self.config.clear()
		self.config = configparser.ConfigParser()

	   # only for information in file
		self.config['PACKAGE'] = {
			'Name_Package': FConfig.__PACKAGE__,
			'Package_Version': FConfig.__VERSION__,
			'Package_Url': FConfig.__URL__
			}
		# etat fileds
		self.config['STATE'] = {
			'NumChannel': form_chaine.get_active(),
			'NumDate': form_jour.get_active(),
			'SbTime': form_sb_time.get_value(),
			'NumQuality': form_quality.get_active(),
			'e_dest': form_e_dest.get_text()
			}
		# pos windows main
		self.config['WIN_MAIN_POS'] = {
			'MAIN_WIN_POS_X' : x,
			'MAIN_WIN_POS_Y': y,
			'WIN_WIDTH': w,
			'WIN_HEIGHT': h
			}

		with open(os.path.join(FConfig.CONFIGFILE, "fricorder.config"), 'w') as configfile:
			self.config.write(configfile)

		for key in self.config:
			print(' '*4 + key)
			for k in self.config[ key ]:
				str_k = "        " + k
				while len(str_k) < 25:
					str_k = str_k + " "
				str_k = str_k + self.config[ key ][ k ]
				print( str_k )

if __name__ == "__main__":
	clg = Preferences()
	clg.Preferences_create_file()
	clg.Preferences_read_file()
